@@ -2,7 +2,6 @@ require_relative '../common'
 require 'net/ssh/authentication/session'
 
 module Authentication
-
   class TestSession < NetSSHTest
     include Net::SSH::Transport::Constants
     include Net::SSH::Authentication::Constants
@@ -168,11 +167,13 @@ module Authentication
 
     private
 
-    def session(options={})
-      @session ||= Net::SSH::Authentication::Session.new(transport(options), options)
+    def session(options = {})
+      session_opts = options.clone
+      session_opts[:pubkey_algorithms] = %w[ssh-rsa]
+      @session ||= Net::SSH::Authentication::Session.new(transport(options), session_opts)
     end
 
-    def transport(options={})
+    def transport(options = {})
       @transport ||= MockTransport.new(options)
     end
 
@@ -292,5 +293,4 @@ module Authentication
       EOF
     end
   end
-
 end
