@@ -5,13 +5,13 @@ if ENV["CI"]
     require 'simplecov'
     SimpleCov.start
 
-    require 'codecov'
-    SimpleCov.formatter = SimpleCov::Formatter::Codecov
+    #    require 'codecov'
+    #    SimpleCov.formatter = SimpleCov::Formatter::Codecov
   end
 end
 
 require 'minitest'
-require 'mocha/setup'
+require 'mocha/minitest'
 require 'net/ssh/buffer'
 require 'net/ssh/config'
 require 'net/ssh/loggable'
@@ -46,6 +46,18 @@ def P(*args)
   Net::SSH::Packet.new(Net::SSH::Buffer.from(*args))
 end
 
+# DH key generate with OpenSSL::PKey::DH.new(512).to_pem
+def dh_512bits_bn
+  OpenSSL::PKey::DH.new(
+    <<~DH_KEY
+      -----BEGIN DH PARAMETERS-----
+      MEYCQQDkZMgCTieW40x/bmCpf6m1XHERNnyOodot21UsJkCidr+T6aAcy/Oz4mWo
+      aYudmZZLQz7jhz0Ut2VQUw0Nz033AgEC
+      -----END DH PARAMETERS-----
+    DH_KEY
+  ).p
+end
+
 class NetSSHTest < Minitest::Test
   def assert_nothing_raised(&block)
     yield
@@ -94,7 +106,7 @@ class MockTransport < Net::SSH::Transport::Session
 
   attr_accessor :mock_enqueue
 
-  def initialize(options={})
+  def initialize(options = {})
     @options = options
     self.logger = options[:logger]
     self.host_as_string = "net.ssh.test,127.0.0.1"
@@ -104,7 +116,7 @@ class MockTransport < Net::SSH::Transport::Session
     @hints = {}
     @socket = options[:socket]
     @algorithms = OpenStruct.new(session_id: "abcxyz123")
-    verifier { |data| true }
+    verifier { |_data| true }
   end
 
   def send_message(message)
@@ -161,7 +173,7 @@ class MockTransport < Net::SSH::Transport::Session
     @server_options = options
   end
 
-  def hint(name, value=true)
+  def hint(name, value = true)
     @hints[name] = value
   end
 end
