@@ -60,6 +60,13 @@ module NetSSH
       end
     end
 
+    def test_start_should_accept_pubkey_algorithms_option
+      assert_nothing_raised do
+        options = { pubkey_algorithms: %w[ssh-rsa] }
+        Net::SSH.start('localhost', 'testuser', options)
+      end
+    end
+
     def test_start_should_accept_remote_user_option
       assert_nothing_raised do
         options = { remote_user: 'foo' }
