@@ -2,6 +2,6 @@ $LOAD_PATH.unshift "#{File.dirname(__FILE__)}/../../lib"
 
 require_relative '../common'
 require 'minitest'
-require 'mocha/setup'
+require 'mocha/minitest'
 require 'pty'
 require 'expect'
